==> CGFeedMaker-1.0.17.tar.gz: CGFeedMaker/action.rsslink.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFeedMaker - A flexible tool for the creation and management
#         of RSS Feeds
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

# An action to create an rss link for a specific feed
if( !isset($params['feed']) )
{
  return false;
}
$feed = trim($params['feed']);

$image = 'images/cms/rss.png';
$imageonly = false;
$text = ''; // use feed name
$imageclass = '';
$linkclass = '';

# Get the feed
$query = 'SELECT * FROM '.cms_db_prefix().'module_cgfeedmaker WHERE name = ?';
$row = $db->GetRow($query,array($feed));
if( !$row )
{
  return false;
}
$text = $row['title'];

if( isset($params['image']) )
{
  $image = trim($params['image']);
}
if( isset($params['text']) )
{
  $text = $params['text'];
}
if( isset($params['imageonly']) )
{
  $imageonly = true;
}
if( isset($params['imageclass']) )
{
  $imageclass = $params['imageclass'];
}
if( isset($params['linkclass']) )
{
  $linkclass = $params['linkclass'];
}

$parms = array();
$parms['feed'] = $feed;
$url = $this->CreateFeedURL($id,$feed,$row['extension']);
if( isset($params['urlonly']) )
{
  echo $url;
  return;
}
if( empty($url) ) die('uhoh '.$feed);

$out = sprintf('<a href="%s" title="%s"',$url,$text);
if( !empty($linkclass) )
{
  $out .= sprintf(' class="%s"',$linkclass);
}
$out .= '>';
if( !empty($image) )
{
  $out .= $this->CreateImageTag($image,$text,'','',$imageclass);
}
if( !$imageonly )
{
  $out .= $text;
}
$out .= '</a>';

echo $out;

#
# EOF
#
?>

==> CGFeedMaker-1.0.19.tar.gz: CGFeedMaker/action.rsslink.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFeedMaker - A flexible tool for the creation and management
#         of RSS Feeds
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

# An action to create an rss link for a specific feed
if( !isset($params['feed']) ) return FALSE;
$feed = trim($params['feed']);

$image = $this->GetModuleURLPath().'/images/tiny_icon.png';
$imageonly = false;
$text = ''; // use feed name
$imageclass = '';
$linkclass = '';

# Get the feed
$query = 'SELECT * FROM '.cms_db_prefix().'module_cgfeedmaker WHERE name = ?';
$row = $db->GetRow($query,array($feed));
if( !$row ) return FALSE;
$text = $row['title'];

if( isset($params['image']) ) $image = trim($params['image']);
if( isset($params['text']) ) return $text;
if( isset($params['imageonly']) ) $imageonly = cms_to_bool($params['imageonly']);
if( isset($params['imageclass']) ) $imageclass = $params['imageclass'];
if( isset($params['linkclass']) ) $linkclass = $params['linkclass'];

$parms = array();
$parms['feed'] = $feed;
$url = $this->CreateFeedURL($id,$feed,$row['extension']);
if( isset($params['urlonly']) ) {
  echo $url;
  return;
}
if( empty($url) ) die('uhoh '.$feed);

$out = sprintf('<a href="%s" title="%s"',$url,$text);
if( !empty($linkclass) ) $out .= sprintf(' class="%s"',$linkclass);

$out .= '>';
if( !empty($image) ) $out .= $this->CreateImageTag($image,$text,'','',$imageclass);

if( !$imageonly )  $out .= $text;
$out .= '</a>';

echo $out;

#
# EOF
#
?>
